import requests


class City:

    def __init__(self, token):
        self.token = token

    def get_cities(self, limit, country_id, min_population):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/cities"

        querystring = {"limit": "3", "countryIds": "DE", "minPopulation": "5000000"}
        # 227ee4eea8mshe252fd0ec651c66p1ce50ajsn6b9eecfbd55a
        headers = {
            'x-rapidapi-key': "2xxxxxxxxxxxxxxxpxxxxxxcfbd55a",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token
        querystring['limit'] = limit
        querystring['countryIds'] = country_id
        querystring['minPopulation'] = min_population

        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()

    def get_city_details(self, city_id):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/cities/REPLACE"

        url = url.replace("REPLACE", city_id)

        headers = {
            'x-rapidapi-key': "2xxxxxxxxxxxxxxxpxxxxxxcfbd55a",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }

        headers['x-rapidapi-key'] = self.token

        response = requests.request("GET", url, headers=headers)

        return response.json()



import requests


class Help:

    def __init__(self, token):
        self.token = token

    def get_list_of_countries(self):
        url = "https://covid-19-data.p.rapidapi.com/help/countries"

        querystring = {"format": "json"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "covid-19-data.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token
        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()

    def get_documentation(self):
        url = "https://covid-19-data.p.rapidapi.com/docs.json"
        # 227ee4eea8mshe252fd0ec651c66p1ce50ajsn6b9eecfbd55a
        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "covid-19-data.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token
        response = requests.request("GET", url, headers=headers)

        return response.json()



import requests


class Country:

    def __init__(self, token):
        self.token = token

    def get_country_details(self, country_id):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/countries/REPLACE"

        url = url.replace("REPLACE", country_id)

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }

        headers['x-rapidapi-key'] = self.token

        response = requests.request("GET", url, headers=headers)

        return response.json()

    def get_country_region_details(self, country_id, region_code):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/countries/COUNTRY_ID/regions/REGION_CODE"
        url = url.replace("COUNTRY_ID", country_id)
        url = url.replace("REGION_CODE", region_code)

        headers = {
            'x-rapidapi-key': "227ee4eea8mshe252fd0ec651c66p1ce50ajsn6b9eecfbd55a",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token

        response = requests.request("GET", url, headers=headers)

        return response.json()



from setuptools import setup, find_packages

setup(name='gk248861',
      version='1.1',
      author='Grzegorz Kuchta',
      author_email='248861@student.pwr.edu.pl',
      packages=find_packages(),
      )



import requests


class Covid:

    def __init__(self, token):
        self.token = token

    def get_daily_report(self, date):
        url = "https://covid-19-data.p.rapidapi.com/report/totals"

        querystring = {"date": "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "covid-19-data.p.rapidapi.com"
        }

        headers['x-rapidapi-key'] = self.token
        querystring['date'] = date

        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()

    def get_latest_totals(self):
        url = "https://covid-19-data.p.rapidapi.com/totals"

        querystring = {"format": "json"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "covid-19-data.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token

        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()

    def get_latest_country_data_by_name(self, country_name):
        url = "https://covid-19-data.p.rapidapi.com/country"

        querystring = {"name": "XXX", "format": "json"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "covid-19-data.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token
        querystring["name"] = country_name

        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()

    def get_daily_report_by_country_name(self, country_name, date):
        url = "https://covid-19-data.p.rapidapi.com/report/country/name"

        querystring = {"name": "XXXXXXXXX", "date": "XXXXXXXXXXXXXX"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "covid-19-data.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token
        querystring["name"] = country_name
        querystring["date"] = date
        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()



import requests


class Administration:

    def __init__(self, token):
        self.token = token

    def get_currencies(self, country_id, limit):
        url = "https://wft-geo-db.p.rapidapi.com/v1/locale/currencies"

        querystring = {"countryId": "X", "limit": "X"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }
        querystring["countryId"] = country_id
        querystring["limit"] = limit
        headers['x-rapidapi-key'] = self.token

        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()

    def get_languages(self, limit):
        url = "https://wft-geo-db.p.rapidapi.com/v1/locale/languages"

        querystring = {"limit": "x"}

        headers = {
            'x-rapidapi-key': "XXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }
        headers['x-rapidapi-key'] = self.token
        querystring['limit'] = limit
        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()



import requests


class Time:

    def __init__(self, token):
        self.token = token

    def get_time_zones(self, limit):
        url = "https://wft-geo-db.p.rapidapi.com/v1/locale/timezones"

        querystring = {"limit": "x"}

        headers = {
            'x-rapidapi-key': "xxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }

        querystring["limit"] = limit
        headers["x-rapidapi-key"] = self.token

        response = requests.request("GET", url, headers=headers, params=querystring)

        return response.json()
